
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.0rc1',
    'branch_nick': 'feature-0-Release__1_23_0rc1_preparation',
    'revision_id': '862b5d1b816f54c25db653e1d55ecc71a9220660',
    'revno': 9902
}
